package com.mcwl.web.controller.communityCenter;


import com.mcwl.communityCenter.domain.Community;
import com.mcwl.communityCenter.service.CommunityService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 社区
 */
@Api(tags = "社区")
@RestController
@RequestMapping("community")
@RequiredArgsConstructor
public class CommunityController {

    private final CommunityService communityService;


    /**
     * 社区列表
     * @return 社区列表
     */
    @ApiOperation(value = "社区列表")
    @GetMapping("list")
    public List<Community> getCommunityList(){
        return communityService.list();
    }


    /**
     * 添加社区
     * @param community 社区
     * @return 添加结果
     */
    @ApiOperation(value = "添加社区")
    @PostMapping("add")
    public boolean addCommunity(@RequestBody Community community){
        return communityService.save(community);
    }

    /**
     * 删除社区
     * @param id 社区id
     * @return 删除结果
     */
    @ApiOperation(value = "删除社区")
    @PostMapping("delete")
    public boolean deleteCommunity(Long id){
        return communityService.removeById(id);
    }

    /**
     * 修改社区
     * @param community 社区
     * @return 修改结果
     */
    @ApiOperation(value = "修改社区")
    @PostMapping("update")
    public boolean updateCommunity(@RequestBody Community community){
        return communityService.updateById(community);
    }

}
